Skip to contents

limit xs retention on the year's total loss: an xol_layer with unlimited cover from 0, annual deductible retention and annual limit limit. It covers the total of the losses it sees: gross, or net of earlier stages in an inuring_tower().

Usage

aggregate_stop_loss(name, limit, retention)

Arguments

name

Layer name, unique within a tower.

limit

Annual limit; may be Inf.

retention

Annual retention.

Value

An xol_layer.

Examples

ceded(aggregate_stop_loss("SL", 50, 100), c(60, 70))
#> [1] 30