Skip to contents

OpinionQA steerability: per question the best alignment over steering prompts, then the mean

Usage

align_opinionqa_steerability(human, steered, positions = NULL)

Arguments

human

A list with one human distribution per question.

steered

A list with one matrix per question, one row per steering prompt.

positions

A list of option positions per question, or NULL.

Value

A number.