Share of the gap from a zero-shot distance to the human noise floor that a model closes
Source:R/align.R
align_relative_improvement.RdShare of the gap from a zero-shot distance to the human noise floor that a model closes
R/align.R
align_relative_improvement.RdShare of the gap from a zero-shot distance to the human noise floor that a model closes