Skip to contents

SimBench score 100 (1 - TVD / TVD_uniform) against the dataset-mean uniform distance (Hu et al., 2026)

Usage

align_simbench(human, model, per_item = FALSE)

Arguments

human, model

Distributions: cells, a matrix with one row per distribution, or a vector.

per_item

Divide item by item instead of by the dataset means.

Value

A number.