Skip to contents

Cells of one question from a table with one column per option

Usage

cells_from_wide(
  frame,
  options,
  cell = "cell_id",
  count = NULL,
  question = "",
  normalise = FALSE
)

Arguments

frame

A data frame with a cell column and one column per option.

options

Option columns in response order.

cell

Cell label column.

count

Respondent count column, or NULL.

question

Question id.

normalise

Divide each row by its total.

Value

A popfidelity_cells object with cells sorted by label.