Skip to contents

A claim count and a severity, with the layer moments treaty pricing needs in closed form. For the layer limit xs attachment applied to each loss, with Y the loss to the layer from one claim, the aggregate has mean E[N] E[Y] and variance E[N] Var[Y] + Var[N] E[Y]^2.

Usage

collective_model(frequency, severity)

Arguments

frequency

A poisson_count, negative_binomial_count or binomial_count.

severity

A severity: lognormal, grid_distribution or a Pareto-family distribution.

Value

A collective_model object.

Details

Supports mean(), variance(), layer() (the aggregate layer mean), layer_variance(), excess_frequency() and simulate_events()-style simulation with collective_simulate().

Examples

m <- collective_model(claim_count(2, 1.5), pareto(1e6, 2))
layer(m, 4e6, 1e6)
#> [1] 1600000
excess_frequency(m, 2e6)
#> [1] 0.5
sqrt(layer_variance(m, 4e6, 1e6))
#> [1] 1969201