Skip to contents

Daily consuse model

Usage

consuse(input, pars, cfs = TRUE)

Arguments

input

A data frame (or matrix with col names), must have columns: flow, pet (units of mm), year, month, day

pars

model parameters in the same format as the sac and snow models, with type=='consuse'

cfs

if TRUE, then flow units of cfs are expected, if FALSE then cms are expected.

Value

data frame with consuse variables