The valid range of the dependence parameter for a copula's family.
Examples
copula_bounds(copula("Clayton", theta = 2))
#> minimum maximum
#> -1 Inf
The valid range of the dependence parameter for a copula's family.
copula_bounds(copula("Clayton", theta = 2))
#> minimum maximum
#> -1 Inf