Model between-level gap in the share answering at or above an option over the survey gap (Chen et al., 2026)
Source:R/dispersion.R
dispersion_gap_inflation.RdModel between-level gap in the share answering at or above an option over the survey gap (Chen et al., 2026)