Skip to contents

Per cell, modal concentration of each side and whether the model exceeds the survey by margin (Ozkan, 2026)

Usage

dispersion_modal_collapse(survey, model, margin = 0.15)

Arguments

survey, model

Cells of the survey and of the model.

margin

Excess concentration that counts as collapse.

Value

A tibble with one row per common cell.