No-op dimensionality reduction strategy.
dr_noop.RdCreates a dimensionality reduction strategy that uses all variables at each
split. This is the default for single trees (pptr).
dr_noop.RdCreates a dimensionality reduction strategy that uses all variables at each
split. This is the default for single trees (pptr).