Extracts the formula used to train a pprf model.
formula.pprf.RdExtracts the formula used to train a pprf model.
Usage
# S3 method for class 'pprf'
formula(x, ...)See also
pprf for training, predict.pprf, summary.pprf
formula.pprf.RdExtracts the formula used to train a pprf model.
# S3 method for class 'pprf'
formula(x, ...)pprf for training, predict.pprf, summary.pprf