Extracts the formula used to train a pptr model.
formula.pptr.RdExtracts the formula used to train a pptr model.
Usage
# S3 method for class 'pptr'
formula(x, ...)See also
pptr for training, predict.pptr, summary.pptr
formula.pptr.RdExtracts the formula used to train a pptr model.
# S3 method for class 'pptr'
formula(x, ...)pptr for training, predict.pptr, summary.pptr