Creates a 3D arrow from from to to, with a cylindrical
shaft and a conical head.
Usage
generate_arrow(
from,
to,
shaft_radius = 0.1,
head_radius = 0.3,
head_length = 0.6,
segments = 32,
color = c(1, 1, 1, 1)
)Creates a 3D arrow from from to to, with a cylindrical
shaft and a conical head.
generate_arrow(
from,
to,
shaft_radius = 0.1,
head_radius = 0.3,
head_length = 0.6,
segments = 32,
color = c(1, 1, 1, 1)
)