Creates a cone from base to tip with the given base
radius, subdivided into segments around the axis.
The base cap is included.
Usage
generate_cone(base, tip, radius = 0.5, segments = 32, color = c(1, 1, 1, 1))Creates a cone from base to tip with the given base
radius, subdivided into segments around the axis.
The base cap is included.
generate_cone(base, tip, radius = 0.5, segments = 32, color = c(1, 1, 1, 1))