Skip to contents

Unions the atom geometries within each code at level.

Usage

geo_geometry(x, level = NULL)

Arguments

x

A Geoscale with geometry attached.

level

Level to dissolve to. Defaults to the atom level.

Value

An sf object with a code column named level plus geometry.

Examples

if (FALSE) { # \dontrun{
geo_geometry(gs, level = "reg32")
} # }