Skip to contents

Discrete spatial representations for optimization and simulation models, including nested sets of regions, conversion between alternative spatial resolutions, and mapping of data onto region hierarchies for modeling and visualization.

Details

Spatial companion to the timescales package.

Author

Maintainer: Oleg Lugovoy olugovoy@optimalsolution.dev (ORCID)

Authors: