Skip to contents

Creates a grouping strategy for regression trees: observations are split by the cutpoint in projected space, then each child's observations are sorted by the continuous response and median-split into 2 new groups for the next projection-pursuit step. This is the default grouping strategy for regression.

Usage

grouping_by_cutpoint()

Value

A grouping_strategy object.

Examples

grouping_by_cutpoint()
#> $name
#> [1] "by_cutpoint"
#> 
#> $display_name
#> [1] "By cutpoint"
#> 
#> attr(,"class")
#> [1] "grouping_strategy"