Label-based grouping strategy.
grouping_by_label.RdCreates a grouping strategy that routes all observations of a group to the same child node. This is the default grouping strategy for classification.
grouping_by_label.RdCreates a grouping strategy that routes all observations of a group to the same child node. This is the default grouping strategy for classification.