Reinsurance tower with inuring order
inuring_tower.RdStages apply in order: each stage's layers see the losses net of all
earlier stages, event by event, with annual terms used up in event order
(see ceded_by_event()).
Arguments
- stages
A list of stages, each a list of xol_layer objects. Layer names must be unique across stages.
Examples
# A 50% quota share inures to the benefit of a 5 xs 5 cover.
tw <- inuring_tower(list(list(quota_share("QS", 0.5)), list(xol_layer("5x5", 5, 5))))
tw@stages
#> [1] 1 2
tower_ceded(tw, 30)
#> QS 5x5
#> 15 5