Skip to contents

Ratios and implied Pareto alphas used in both primary and reinsurance pricing:

Usage

ilf(severity, limit, basic_limit)

loss_elimination_ratio(severity, deductible)

pareto_extrapolation(from, to, alpha, truncation = NULL)

alpha_between_layers(a, b, truncation = NULL)

alpha_between_frequency_and_layer(
  threshold,
  frequency,
  limit,
  attachment,
  expected_loss,
  truncation = NULL
)

alpha_between_frequencies(
  threshold_1,
  frequency_1,
  threshold_2,
  frequency_2,
  truncation = NULL
)

Arguments

severity

A severity.

limit, basic_limit, deductible

Numeric.

from, to, a, b

Layers, as described above.

alpha

Pareto alpha.

truncation

Pareto truncation point, or NULL.

threshold, frequency

A frequency above a threshold.

attachment, expected_loss

The layer for alpha_between_frequency_and_layer().

threshold_1, frequency_1, threshold_2, frequency_2

Two frequencies.

Value

A numeric vector (ilf, loss_elimination_ratio) or a single number.

Details

  • ilf(severity, limit, basic_limit): increased limit factors LEV(limit) / LEV(basic_limit);

  • loss_elimination_ratio(severity, deductible): LEV(d) / E[X];

  • pareto_extrapolation(from, to, alpha): expected loss of layer to per unit of expected loss of layer from, layers as c(limit, attachment);

  • alpha_between_layers(a, b): the alpha at which two layers, as c(limit, attachment, expected_loss), have their losses;

  • alpha_between_frequency_and_layer() and alpha_between_frequencies(): the alpha between a frequency above a threshold and a layer, or two frequencies.

Examples

p <- pareto(100, 2)
ilf(p, c(500, 1000), 200)
#> [1] 1.200000 1.266667
loss_elimination_ratio(p, 150)
#> [1] 0.6666667
pareto_extrapolation(c(1e6, 1e6), c(2e6, 2e6), 2)
#> [1] 0.5
alpha_between_frequencies(1e6, 4, 2e6, 1)
#> [1] 2