Majority-vote leaf strategy.
leaf_majority_vote.RdCreates a leaf strategy that assigns the majority group label as the leaf prediction. When groups are tied, the smallest label wins. This is the default leaf strategy for classification.
leaf_majority_vote.RdCreates a leaf strategy that assigns the majority group label as the leaf prediction. When groups are tied, the smallest label wins. This is the default leaf strategy for classification.