leaf_mean_response.Rd
Creates a leaf strategy that predicts the mean of the continuous response values for the observations in the leaf. Used for regression trees; requires a numeric response.
leaf_mean_response()
A leaf_strategy object.
leaf_strategy
pptr, pprf, leaf_majority_vote
pptr
pprf
leaf_majority_vote
leaf_mean_response() #> $name #> [1] "mean_response" #> #> $display_name #> [1] "Mean response" #> #> attr(,"class") #> [1] "leaf_strategy"