Skip to contents

The local Pareto alpha alpha0 * (1 + gamma * log(x / t)) rises linearly in the log of the amount, so with L = log(x / t), P(X > x) = exp(-alpha0 L - alpha0 gamma L^2 / 2). Give either gamma or delta = alpha0 * gamma * log(2), the rise in alpha each time the amount doubles. Properties: d@t, d@alpha0, d@gamma, d@delta.

Usage

log_affine_pareto(t, alpha0, gamma = NULL, delta = NULL, ptr = NULL)

Arguments

t

Threshold; finite and positive.

alpha0

Local alpha at t; finite and positive.

gamma

Non-negative; 0 gives the Pareto.

delta

Alternative to gamma.

ptr

Internal: an existing object to wrap.

Value

A log_affine_pareto object, which inherits from distribution.

Details

Supports the same operations as pareto, and local_alpha().

Examples

d <- log_affine_pareto(1e6, 1.5, delta = 0.5)
local_alpha(d, 2e6)
#> [1] 2
layer(d, 4e6, 1e6)
#> [1] 887176.9