Skip to contents

One collective model (a frequency and a piecewise Pareto severity) that reproduces the expected loss of every layer of a tower (Riegel 2018, Matching Algorithm 2).

Usage

match_tower(
  attachments,
  layer_losses,
  frequencies = NULL,
  rule = c("minimize", "midpoint")
)

Arguments

attachments

Increasing attachment points; layer i runs to the next one, the last is unlimited.

layer_losses

Expected loss a year of each layer.

frequencies

Expected losses a year above each attachment point, NA where to derive them, or NULL to derive all.

rule

"minimize" (make the two alphas in each layer as close as possible) or "midpoint".

Value

A tower_model.

Examples

m <- match_tower(c(1000, 1500, 2000, 2500, 3000, 5000, 10000),
                 c(100, 90, 50, 40, 100, 50, 50),
                 frequencies = c(0.25, rep(NA, 6)))
layer(m, 500, 1500)
#> [1] 90