Skip to contents

The MBBEFD class of Bernegger (1997) for property per-risk exposure rating: G(x) is the share of a risk's expected loss below the fraction x of its maximum possible loss (MPL), and 1/g the probability of a total loss. swiss_re_curve(c) gives Bernegger's one-parameter family, b = exp(3.1 - 0.15 (1 + c) c), g = exp((0.78 + 0.12 c) c): c = 1.5, 2, 3, 4 are the Swiss Re curves and c = 5 the Lloyd's curve.

Usage

mbbefd(b, g, ptr = NULL)

swiss_re_curve(c)

exposure_curve(curve, x)

exposure_layer_share(curve, limit, attachment, mpl)

severity_exposure_curve(severity, mpl, x)

rate_quantile(curve, u)

Arguments

b, g

MBBEFD parameters, b >= 0, g >= 1.

c

Swiss Re curve parameter, non-negative (0 is the straight line).

curve

An mbbefd or tabulated_curve object.

x

Fractions of the MPL.

limit, attachment

The layer.

mpl

Maximum possible loss of the risk.

severity

A severity: lognormal, grid_distribution or a Pareto-family distribution.

u

Probabilities in (0, 1).

Value

mbbefd() and swiss_re_curve(): an mbbefd object with properties b, g, mean (the mean destruction rate) and total_loss_probability. The others: numeric vectors.

Details

exposure_curve() evaluates G; exposure_layer_share() is the share of a risk's expected loss in the layer limit xs attachment, `G(min((a

  • l)/M, 1)) - G(min(a/M, 1)). severity_exposure_curve()is the curve of any severity capped at the MPL,LEV(x M) / LEV(M)`.

Examples

c3 <- swiss_re_curve(3)
exposure_curve(c3, c(0.1, 0.5, 1))
#> [1] 0.4055595 0.7768809 1.0000000
exposure_layer_share(c3, 5e6, 5e6, 10e6)
#> [1] 0.2231191
severity_exposure_curve(pareto(1e5, 1.5), 1e7, c(0.5, 1))
#> [1] 0.9704133 1.0000000