Skip to contents

Shannon entropy of each row in the given log base

Usage

metric_entropy(cells, base = 2)

Arguments

cells

Cells or a matrix with one distribution per row.

base

Logarithm base.

Value

A numeric vector.