Skip to contents

The scalar or vector parameters specific to a multivariate family, beyond mean/covariance: df for "MultivariateStudentT"; alpha and alpha_sum for "Dirichlet"; trials and probabilities for "Multinomial".

Usage

mvdist_params(mv)

Arguments

mv

a corehydro_mvdist of family "MultivariateStudentT", "Dirichlet", or "Multinomial".

Value

a named list with the entries relevant to mv's family.

Examples

mvdist_params(mvdist_student_t(5, c(0, 0)))
#> $df
#> [1] 5
#> 
mvdist_params(mvdist_dirichlet(c(2, 3, 4)))
#> $alpha
#> [1] 2 3 4
#> 
#> $alpha_sum
#> [1] 9
#> 
mvdist_params(mvdist_multinomial(10, c(0.2, 0.3, 0.5)))
#> $trials
#> [1] 10
#> 
#> $probabilities
#> [1] 0.2 0.3 0.5
#>