Should be used on continuous data only. When z is non-empty, uses linear regression residuals to compute the partial correlation. Pass a 0-column matrix for z to run unconditionally. When boolean is true, returns an independence verdict instead of the raw test statistic and p-value.

pearson_correlation_test(x_values, y_values, z, boolean, significance_level)