Population Fidelity Score, its components and diagnostics on the cells both sides share
Source:R/pfs.R
pfs_score.RdPopulation Fidelity Score, its components and diagnostics on the cells both sides share
Usage
pfs_score(survey, model, variant = pfs_variant(), threads = NULL)Arguments
- survey, model
Cells of the survey and of the model; scored on their common cells.
- variant
A specification from
pfs_variant().- threads
Worker threads;
NULLreadspopfidelity.threadsorPOPFIDELITY_THREADS, else 2.
Examples
toy <- example_toy()
pfs_score(toy$survey, toy$M2)$pfs
#> [1] 0.8448182