phone_finder: Phone Finder

phone_finderR Documentation

Phone Finder

Description

phone_finder Search phone are based on the email You give one email and it returns phone data.

Usage

phone_finder(obj, email)

## S4 method for signature 'Tomba'
phone_finder(obj, email)

Arguments

obj

Tomba class

email

a character The email address you want to find phone.

Value

A list phone data containing the: local_format,intl_format,country_code,line_type,carrier,timezones

References

https://developer.tomba.io/#phone-finder

Examples

## Not run: 
client <- Tomba(key="ta_xxxx",secret="ts_xxxx")
result <- phone_finder(client,email="******@zapier.com")

## End(Not run)

tomba-io/r documentation built on June 1, 2025, 10:12 p.m.