Skip to contents

Predicts numeric responses from a pprf model (regression mode).

Usage

# S3 method for class 'pprf_regression'
predict(object, new_data = NULL, type = NULL, ...)

Arguments

object

A pprf_regression model.

new_data

A data frame or matrix of new observations.

type

Must be "response" (default).

...

For backward compatibility, the first positional argument is treated as new_data when new_data is NULL.

Value

A numeric vector of mean predictions across the forest's trees.