Skip to contents

Each row's dispersion from the dispersion model of a booster_fit() with dispersion_model = TRUE, or the constant dispersion for every row otherwise.

Usage

predict_dispersion(object, newdata)

Arguments

object

A booster_model.

newdata

A data frame with the model's terms.

Value

One dispersion per row of newdata.