Skip to contents

Loads a data dictionary from a YAML file conforming to the data-dict spec. The dictionary is returned as a plain list and can be passed directly to QueryChat via the data_dict argument.

If name is absent from the YAML file, it defaults to the file stem.

Usage

read_data_dict(path)

Arguments

path

Path to the YAML file.

Value

A named list with the structure of the YAML file.