Skip to contents

Every record under a run directory or in one JSON-lines file, the latest per prompt, flattened

Usage

read_records(path)

Arguments

path

A run directory or a JSON-lines file written by the elicitation.

Value

A tibble with one row per question, mode and prompt; shares is a list column.