Skip to contents

Intraclass correlation of a subjects-by-runs table (Shrout and Fleiss, 1979; McGraw and Wong, 1996)

Usage

reliability_icc(ratings, model = "agreement", average = FALSE)

Arguments

ratings

A table with one row per subject and one column per run or rater.

model

"oneway", "consistency" or "agreement".

average

Reliability of the average of the columns instead of a single one.

Value

A number.