Share of items whose two answer indices differ, such as first-token versus text (Wang et al., 2024)
Source:R/reliability.R
reliability_mismatch_rate.RdShare of items whose two answer indices differ, such as first-token versus text (Wang et al., 2024)