A short Markdown report: the population rows, then the subgroups with the lowest PFS
Source:R/report.R
report_markdown.RdA short Markdown report: the population rows, then the subgroups with the lowest PFS
Arguments
- groups
A table from
pfs_score_groups().- title
Report title.
- worst
Number of subgroups listed.