Skip to contents

Returns y - fitted(model). Only defined for regression models — classification residuals have no canonical scalar form, so this method errors on classification models rather than inventing a convention.

Usage

# S3 method for class 'ppmodel'
residuals(object, ...)

Arguments

object

A pprf or pptr regression model.

...

Unused.

Value

A numeric vector of length nobs(object).

See also