Mean-of-means split rule strategy.
sr_mean_of_means.RdCreates a split rule strategy that splits at the midpoint between group means. This is the default (and currently only) split rule.
See also
pptr, pprf, pp_pda, dr_uniform
sr_mean_of_means.RdCreates a split rule strategy that splits at the midpoint between group means. This is the default (and currently only) split rule.
pptr, pprf, pp_pda, dr_uniform