Mantel test of two condensed distance matrices on the same cells, permuting cells (Mantel, 1967)
Source:R/structure.R
structure_mantel.RdMantel test of two condensed distance matrices on the same cells, permuting cells (Mantel, 1967)
Usage
structure_mantel(
first,
second,
method = "spearman",
permutations = 999L,
alternative = "greater",
seed = 0,
threads = NULL
)