Skip to contents

Discrete time representations for optimization and simulation models, including calendar-based nested sets of timeframes, conversion between alternative temporal resolutions, and mapping of data onto calendar grids for modeling and visualization.

Details

Successor to the 'timeslices' package; companion to 'geoscales' for the spatial dimension.

Author

Maintainer: Oleg Lugovoy olugovoy@optimalsolution.dev (ORCID)

Authors: