Vertex colors and normals are untouched: a translation does not change the orientation of a surface.
Examples
mesh <- generate_cuboid(c(0, 0, 0), c(1, 1, 1))
moved <- translate_mesh(mesh, c(5, 0, 0))
colMeans(moved$vertices)
#> [1] 5 0 0
Vertex colors and normals are untouched: a translation does not change the orientation of a surface.
mesh <- generate_cuboid(c(0, 0, 0), c(1, 1, 1))
moved <- translate_mesh(mesh, c(5, 0, 0))
colMeans(moved$vertices)
#> [1] 5 0 0