Mean of a few run values and the half-width t(1 - a/2, n - 1) s / sqrt(n)
Source:R/uncertainty.R
uncertainty_mean_interval.RdMean of a few run values and the half-width t(1 - a/2, n - 1) s / sqrt(n)
R/uncertainty.R
uncertainty_mean_interval.RdMean of a few run values and the half-width t(1 - a/2, n - 1) s / sqrt(n)