Quantile of Student's t distribution, computed in the core so Python and R agree
Source:R/uncertainty.R
uncertainty_t_quantile.RdQuantile of Student's t distribution, computed in the core so Python and R agree
R/uncertainty.R
uncertainty_t_quantile.RdQuantile of Student's t distribution, computed in the core so Python and R agree