All-variables selection strategy.
vars_all.RdCreates a variable selection strategy that uses all variables at each
split. This is the default for single trees (pptr).
vars_all.RdCreates a variable selection strategy that uses all variables at each
split. This is the default for single trees (pptr).