Each cell's survey answer shares: one-hot answers in option order, averaged over valid answers
Source:R/aggregate.R
aggregate_survey.RdEach cell's survey answer shares: one-hot answers in option order, averaged over valid answers
Arguments
- respondents
A data frame with one row per respondent.
- question
A question from
read_questions().- cell
Cell label column.
- answer
Answer column, or
NULLfor the question id.- weight
Survey weight column, or
NULL.