OpinionQA steerability: per question the best alignment over steering prompts, then the mean
Source:R/align.R
align_opinionqa_steerability.RdOpinionQA steerability: per question the best alignment over steering prompts, then the mean
R/align.R
align_opinionqa_steerability.RdOpinionQA steerability: per question the best alignment over steering prompts, then the mean