Cells of one question from a long table with one row per cell and option
Source:R/cells.R
cells_from_long.RdCells of one question from a long table with one row per cell and option
Usage
cells_from_long(
frame,
question = NULL,
options = NULL,
cell = "cell_id",
option = "option",
share = "share",
count = "n"
)