R/chat.R
chat_get_greeting.Rd
Get the current greeting content
chat_get_greeting(id, session = getDefaultReactiveDomain())
The ID of the chat element
The Shiny session object
A character string with the current greeting content, or NULL if no greeting is set or has been cleared.
NULL