Per cell, modal concentration of each side and whether the model exceeds the survey by margin (Ozkan, 2026)
Source: R/dispersion.R
dispersion_modal_collapse.RdPer cell, modal concentration of each side and whether the model exceeds the survey by margin (Ozkan, 2026)