Facets from a table with one row per cell and one column per demographic family
Source:R/facets.R
facets_from_frame.RdFacets from a table with one row per cell and one column per demographic family
Usage
facets_from_frame(
frame,
cell = "cell_id",
families = NULL,
orders = NULL,
missing = MISSING_TOKENS
)