Creates a cylinder from start to end with the given
radius, subdivided into segments around the axis.
Both end caps are included.
Usage
generate_cylinder(
start,
end,
radius = 0.5,
segments = 32,
color = c(1, 1, 1, 1)
)Creates a cylinder from start to end with the given
radius, subdivided into segments around the axis.
Both end caps are included.
generate_cylinder(
start,
end,
radius = 0.5,
segments = 32,
color = c(1, 1, 1, 1)
)