Density, distribution, and quantile functions for the Generalized Extreme
Value (GEV) distribution, parameterised by location \(\xi\), scale
\(\alpha\), and shape \(\kappa\). These wrap the shared C++ core ported
from the USACE-RMC Numerics library.
Usage
dgev(x, location = 0, scale = 1, shape = 0)
pgev(q, location = 0, scale = 1, shape = 0)
qgev(p, location = 0, scale = 1, shape = 0)
Arguments
- x, q
numeric vector of quantiles.
- location
location parameter \(\xi\).
- scale
scale parameter \(\alpha\) (must be positive).
- shape
shape parameter \(\kappa\).
- p
numeric vector of probabilities.
Value
A numeric vector the same length as x, q, or p.
Examples
dgev(100, location = 100, scale = 10, shape = 0)
#> [1] 0.03678794
qgev(0.99, location = 10849, scale = 5745.6, shape = 0.005)
#> [1] 36977.97