Cutpoint-based grouping strategy (regression).
grouping_by_cutpoint.RdCreates a grouping strategy for regression trees: observations are split by the cutpoint in projected space, then each child's observations are sorted by the continuous response and median-split into 2 new groups for the next projection-pursuit step. This is the default grouping strategy for regression.