Layer rating
layer_rating.RdRatios and implied Pareto alphas used in both primary and reinsurance pricing:
Usage
ilf(severity, limit, basic_limit)
loss_elimination_ratio(severity, deductible)
pareto_extrapolation(from, to, alpha, truncation = NULL)
alpha_between_layers(a, b, truncation = NULL)
alpha_between_frequency_and_layer(
threshold,
frequency,
limit,
attachment,
expected_loss,
truncation = NULL
)
alpha_between_frequencies(
threshold_1,
frequency_1,
threshold_2,
frequency_2,
truncation = NULL
)Arguments
- severity
A severity.
- limit, basic_limit, deductible
Numeric.
- from, to, a, b
Layers, as described above.
- alpha
Pareto alpha.
- truncation
Pareto truncation point, or
NULL.- threshold, frequency
A frequency above a threshold.
- attachment, expected_loss
The layer for
alpha_between_frequency_and_layer().- threshold_1, frequency_1, threshold_2, frequency_2
Two frequencies.
Details
ilf(severity, limit, basic_limit): increased limit factorsLEV(limit) / LEV(basic_limit);loss_elimination_ratio(severity, deductible):LEV(d) / E[X];pareto_extrapolation(from, to, alpha): expected loss of layertoper unit of expected loss of layerfrom, layers asc(limit, attachment);alpha_between_layers(a, b): the alpha at which two layers, asc(limit, attachment, expected_loss), have their losses;alpha_between_frequency_and_layer()andalpha_between_frequencies(): the alpha between a frequency above a threshold and a layer, or two frequencies.