Match a reinsurance tower
match_tower.RdOne collective model (a frequency and a piecewise Pareto severity) that reproduces the expected loss of every layer of a tower (Riegel 2018, Matching Algorithm 2).
Usage
match_tower(
attachments,
layer_losses,
frequencies = NULL,
rule = c("minimize", "midpoint")
)Arguments
- attachments
Increasing attachment points; layer
iruns to the next one, the last is unlimited.- layer_losses
Expected loss a year of each layer.
- frequencies
Expected losses a year above each attachment point,
NAwhere to derive them, orNULLto derive all.- rule
"minimize"(make the two alphas in each layer as close as possible) or"midpoint".
Value
A tower_model.