Mixture of severities
mixture_distribution.RdA loss from component i with probability weights[i]: attritional and
large losses in one severity. Distribution functions, limited expected
values and layer moments are the weighted sums of the components'.
Property: d@weights.
Arguments
- weights
Positive weights summing to 1.
- components
A list of severities (lognormal, gamma_distribution, weibull_distribution, Pareto-family, ...).
- ptr
Internal: an existing object to wrap.
Value
A mixture_distribution object, which inherits from
distribution.
Details
Supports the same operations as pareto, and can be discretized or used
in simulate_events().
Examples
m <- mixture_distribution(c(0.9, 0.1), list(lognormal_from_mean_cv(1e4, 1), pareto(1e5, 2)))
mean(m)
#> [1] 29000