Out-of-bag predictions for a random forest.
oob_predictions.RdReturns predictions for each training row using only trees that did not see that row in their bootstrap sample. Observations with no OOB tree are represented as `NA` in both modes: `NA` at the factor level for classification, and `NA_real_` for regression. Filter with the standard `is.na()` idiom.