Crosses the supplied counterbalancing factors and replicates the cells to
cover n_participants, generalising the expand.grid() + replication pattern
of the original workflow's participant_parameters.R.
Crosses the supplied counterbalancing factors and replicates the cells to
cover n_participants, generalising the expand.grid() + replication pattern
of the original workflow's participant_parameters.R.