Sums the distances between consecutive points, plus the closing distance from
the last point back to the first for a closed path. Useful to pick a
sensible step for resample_path, or to derive a sampling
density from the size of the data.
Sums the distances between consecutive points, plus the closing distance from
the last point back to the first for a closed path. Useful to pick a
sensible step for resample_path, or to derive a sampling
density from the size of the data.