| phone_finder | R Documentation |
phone_finder Search phone are based on the email You give one email and it returns phone data.
phone_finder(obj, email)
## S4 method for signature 'Tomba'
phone_finder(obj, email)
obj |
Tomba class |
email |
a character The email address you want to find phone. |
A list phone data containing the: local_format,intl_format,country_code,line_type,carrier,timezones
https://developer.tomba.io/#phone-finder
## Not run:
client <- Tomba(key="ta_xxxx",secret="ts_xxxx")
result <- phone_finder(client,email="******@zapier.com")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.