Dispersion per row of a boosted model
predict_dispersion.RdEach row's dispersion from the dispersion model of a booster_fit() with
dispersion_model = TRUE, or the constant dispersion for every row
otherwise.
predict_dispersion.RdEach row's dispersion from the dispersion model of a booster_fit() with
dispersion_model = TRUE, or the constant dispersion for every row
otherwise.