Every question of a long cells table, keyed by question, after keeping rows that match the filters
Source:R/io.R
read_cells.RdEvery question of a long cells table, keyed by question, after keeping rows that match the filters
Arguments
- path
Path to a long cells table.
- questions
Questions from
read_questions()for option orders, orNULL.- ...
Filters such as
source = "M1".
Examples
survey <- read_cells(example_path("toy", "survey_cells.csv"))
names(survey)
#> [1] "toy" "toy_scale"