Residuals from a regression ppforest2 model.
residuals.ppmodel.RdReturns y - fitted(model). Only defined for regression models —
classification residuals have no canonical scalar form, so this method
errors on classification models rather than inventing a convention.
Usage
# S3 method for class 'ppmodel'
residuals(object, ...)