Skip to contents

Replace ptps column with ptps derived using rain snow line code (lapse rate + MAT)

Usage

rsnwelev(forcing, pars, ae_tbl)

Arguments

forcing

data frame with columns for forcing inputs

pars

rsnwelev and snow17 parameters

ae_tbl

data.table with col1 containing quantile info and subsequent col with elev for each zone

Value

Matrix (1 column per zone) of the forcing input argument with ptps replaced with that derived from rsnwelev model

Examples

if (FALSE) { # \dontrun{
data(nrkw1_forcing)
data(nrkw1_pars)
forcing_adj <- rsnwelev(nrkw1_forcing, nrkw1_pars, area_elev_curve)
} # }