Skip to contents

Execute SAC-SMA, SNOW17, return total channel inflow per zone, and model states

Usage

sac_snow(dt_hours, forcing, pars, return_states = FALSE)

Arguments

dt_hours

timestep in hours

forcing

data frame with with columns for forcing inputs

pars

sac parameters

return_states

logical value indicating if the states should be output as well as the tci

Value

data.frame (1 column per zone) of unrouted channel inflow (tci), sac states uztwc, uzfwc, lztwc, lzfsc, lzfpc, adimc, and snow water equivalent (swe), and adjusted forcing data.

Examples

if (FALSE) { # \dontrun{
data(nrkw1_forcing)
data(nrkw1_pars)
dt_hours <- 6
flow <- sac_snow(dt_hours, nrkw1_forcing, nrkw1_pars)
} # }