Skip to contents

Execute SAC-SMA, SNOW17, return total channel inflow per zone, and model states

Usage

sac_snow_states(dt_hours, forcing, pars)

Arguments

dt_hours

timestep in hours

forcing

data frame with with columns for forcing inputs

pars

sac parameters

Value

data.frame (1 column per zone) of unrouted channel inflow (tci), sac states uztwc, uzfwc, lztwc, lzfsc, lzfpc, adimc, and snow water equivalent (swe), and adjusted forcing data.

Examples

if (FALSE) { # \dontrun{
data(nrkw1_forcing)
data(nrkw1_pars)
dt_hours <- 6
states <- sac_snow_states(dt_hours, nrkw1_forcing, nrkw1_pars)
} # }