Pure-node stopping rule.
stop_pure_node.RdCreates a stopping rule that stops splitting when a node contains only one group. This is the default stopping rule for classification.
stop_pure_node.RdCreates a stopping rule that stops splitting when a node contains only one group. This is the default stopping rule for classification.