timescales: Nested Timeframes and Calendars for Modeling
Source:R/timescales-package.R
timescales-package.RdDiscrete time representations for optimization and simulation models, including calendar-based nested sets of timeframes, conversion between alternative temporal resolutions, and mapping of data onto calendar grids for modeling and visualization.
Author
Maintainer: Oleg Lugovoy olugovoy@optimalsolution.dev (ORCID)
Authors:
Oleg Lugovoy olugovoy@optimalsolution.dev (ORCID)