Two parameter unit hydrograph routing for one or more basin zones
Arguments
- dt_hours
timestep in hours
- tci
channel inflow matrix, one column per zone
- pars
parameters
- sum_zones
should routed flows from multiple zones be added and returned as a vector, or kept separate and returned as a matrix
- start_of_timestep
should the output flow data be shifted by one timestep to account for forcing data that uses beginning of timestep labeling
- backfill
when start_of_timestep is TRUE, should the first value be duplicated
Examples
# Simple: full model chain via the bundled example; routed flow per zone
run <- load_example("NRKW1")
head(run$sacsnow_sf)
#> [1] 485.2846 485.2846 629.8530 661.1905 661.5767 653.3307
# Low-level: run FA -> SAC-SMA/SNOW17 to get TCI, then route it with UH.
data(nrkw1_forcing)
data(nrkw1_pars)
dt_hours <- 6
forcing_adj <- fa_nwrfc(dt_hours, nrkw1_forcing, nrkw1_pars)
tci <- sac_snow(dt_hours, forcing_adj, nrkw1_pars)
flow_cfs <- uh(dt_hours, tci, nrkw1_pars)