Two parameter unit hydrograph routing for one or more basin zones
Arguments
- dt_hours
timestep in hours
- tci
channel inflow matrix, one column per zone
- pars
parameters
- sum_zones
should routed flows from multiple zones be added and returned as a vector, or kept separate and returned as a matrix
- start_of_timestep
should the output flow data be shifted by one timestep to account for forcing data that uses beginning of timestep labeling
- backfill
when start_of_timestep is TRUE, should the first value be duplicated