Returns ordinates for a 2 parameter (shape,scale) gamma unit hydrograph. The ordinates are
based on the given timestep (in hours). To match the Fortran code, a max length is used.
A warning is issued if the UH does not terminate before the given max length.
Usage
uh2p(shape, scale, timestep, max_len = 1000)
Arguments
- shape
gamma shape parameter
- scale
gamma scale parameter
- timestep
timestep in hours
- max_len
max length of the uh
Value
vector of ordinates for a 2 parameter (shape,scale) gamma unit hydrograph
Examples
dt <- 6
shape <- 2
scale <- 1
y <- uh2p(2, 1, 6)
x <- seq(dt, dt * length(y), by = dt)
plot(x, y, t = "l")